@@ -4,6 +4,7 @@
  */
 
 #include "cachemanager.h"
+#include "embedded_config.h"
 #include <QCryptographicHash>
 #include <QFile>
 #include <QDir>
@@ -11,17 +12,17 @@
 #include <QCoreApplication>
 #include <QFileInfo>
 #include <functional>
-#include "buffer_optimization.h"
+#include "systemmemorymanager.h"
 #include "config.h"
 
-// Hash algorithm used for cache verification
-#define CACHE_HASH_ALGORITHM QCryptographicHash::Sha256
+// Hash algorithm used for cache verification (use same as OS list verification)
+#define CACHE_HASH_ALGORITHM OSLIST_HASH_ALGORITHM
 
-CacheManager::CacheManager(bool embeddedMode, QObject *parent)
+CacheManager::CacheManager(QObject *parent)
     : QObject(parent)
-    , workerThread_(new QThread(this))
+    , workerThread_(new QThread())  // Don't parent to avoid Qt's automatic deletion
     , worker_(new CacheVerificationWorker())
-    , cachingEnabled_(!embeddedMode)
+    , cachingEnabled_(!::isEmbeddedMode())
 {
     // Move worker to background thread
     worker_->moveToThread(workerThread_);
@@ -45,12 +46,36 @@ CacheManager::CacheManager(bool embeddedMode, QObject *parent)
 
 CacheManager::~CacheManager()
 {
-    if (workerThread_->isRunning()) {
+    qDebug() << "CacheManager destructor: cleaning up background thread";
+    
+    // Disconnect all signals to prevent any further communication
+    disconnect(worker_, nullptr, this, nullptr);
+    
+    if (workerThread_ && workerThread_->isRunning()) {
+        // Request thread to quit gracefully
         workerThread_->quit();
-        workerThread_->wait(5000); // Wait up to 5 seconds
+        
+        // Wait for thread to finish
+        if (!workerThread_->wait(5000)) {
+            qDebug() << "CacheManager: Thread did not quit within 5 seconds, terminating";
+            workerThread_->terminate();
+            workerThread_->wait(2000);
+        }
     }
     
-    worker_->deleteLater();
+    // Clean up worker object
+    if (worker_) {
+        delete worker_;
+        worker_ = nullptr;
+    }
+    
+    // Clean up thread object
+    if (workerThread_) {
+        delete workerThread_;
+        workerThread_ = nullptr;
+    }
+    
+    qDebug() << "CacheManager destructor: cleanup complete";
 }
 
 void CacheManager::startBackgroundOperations()
@@ -283,12 +308,15 @@ void CacheManager::onVerificationComplete(bool isValid, const QString& fileName,
 {
     qDebug() << "Cache verification complete for" << fileName << "- Valid:" << isValid;
     
+    QByteArray uncompressedHashForUI;
+    
     updateCacheStatus([&](CacheStatus& status) {
         status.isValid = isValid;
         status.verificationComplete = true;
         status.cacheFileName = fileName;
-        // Don't update cachedHash here - keep the compressed hash for UI queries
-        // The 'hash' parameter is the uncompressed hash used for verification
+        // Don't overwrite cachedHash - it already contains the uncompressed hash for UI matching
+        // The 'hash' parameter is the compressed hash used for verification
+        uncompressedHashForUI = status.cachedHash; // Get the uncompressed hash for UI update
     });
     
     qDebug() << "Updated cache status after verification:";
@@ -301,6 +329,12 @@ void CacheManager::onVerificationComplete(bool isValid, const QString& fileName,
     
     emit cacheVerificationComplete(isValid);
     
+    // Also emit cacheFileUpdated when verification succeeds to trigger UI update
+    if (isValid && !uncompressedHashForUI.isEmpty()) {
+        qDebug() << "Emitting cacheFileUpdated signal after successful verification";
+        emit cacheFileUpdated(uncompressedHashForUI); // UI matches against uncompressed hash
+    }
+    
     if (getCacheStatus().diskSpaceCheckComplete) {
         emit cacheOperationsReady();
     }
@@ -429,8 +463,8 @@ void CacheVerificationWorker::verifyCacheFile(const QString& fileName, const QBy
             
             qint64 fileSize = cacheFile.size();
             
-            // Use centralized buffer optimization module for consistent buffer sizing
-            qint64 bufferSize = getAdaptiveVerifyBufferSize(fileSize);
+            // Use centralized SystemMemoryManager for consistent buffer sizing
+            qint64 bufferSize = SystemMemoryManager::instance().getAdaptiveVerifyBufferSize(fileSize);
             
             // Allocate buffer on heap for large sizes
             std::unique_ptr<char[]> buffer = std::make_unique<char[]>(bufferSize);
