@@ -38,7 +38,7 @@ private:
 };
 
 AcceleratedCryptographicHash::AcceleratedCryptographicHash(QCryptographicHash::Algorithm method)
-    : p_Impl(std::make_unique<impl>(method)) {}
+    : p_Impl(std::make_unique<impl>(method)), _algo(method) {}
 
 AcceleratedCryptographicHash::~AcceleratedCryptographicHash() = default;
 
@@ -51,3 +51,9 @@ void AcceleratedCryptographicHash::addData(const QByteArray &data) {
 QByteArray AcceleratedCryptographicHash::result() const {
     return p_Impl->result();
 }
+
+void AcceleratedCryptographicHash::reset() {
+    p_Impl = std::make_unique<impl>(_algo);
+    _cachedResult.clear();
+    _resultCached = false;
+}
