@@ -32,9 +32,28 @@ class MacOSFileOperations : public FileOperations {
   FileError Close() override;
   bool IsOpen() const override;
 
+  // Streaming I/O operations
+  FileError WriteSequential(const std::uint8_t* data, std::size_t size) override;
+  FileError ReadSequential(std::uint8_t* data, std::size_t size, std::size_t& bytes_read) override;
+  
+  // File positioning
+  FileError Seek(std::uint64_t position) override;
+  std::uint64_t Tell() const override;
+  
+  // Sync operations
+  FileError ForceSync() override;
+  FileError Flush() override;
+  
+  // Handle access
+  int GetHandle() const override;
+
+  // Get the last errno error code
+  int GetLastErrorCode() const override;
+
  private:
   int fd_;
   std::string current_path_;
+  int last_error_code_;
   
   FileError OpenInternal(const char* path, int flags, mode_t mode = 0);
 };
